@@ -1,5 +1,5 @@
 """
 This module exists only for backwards compatibility.
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from lino.api.ad import *
