@@ -341,11 +341,10 @@ class Action(Parametrizable, Permittable):
 
     hide_top_toolbar = False  # 20210509
     """
-    Move toolbar to bottom on the window opened by this action.
+    This is set to `True` for :class:`ShowInsert`.
 
-    This is used by ExtJS for ShowInsert, but has no effect in React.
-
-    TODO: rename this to something like ``toolbar_location = "bottom"``.
+    As an applicationdeveloper you don't need this action attribute, but
+    see :attr:`lino.core.actors.Actor.hide_top_toolbar`.
 
     """
     hide_navigator = False  # 20210509
@@ -477,8 +476,8 @@ class Action(Parametrizable, Permittable):
         return InstanceAction(
             self, instance.get_default_table(), instance, owner)
 
-    def get_a_href_target(self):
-        return None
+    # def get_a_href_target(self):
+    #     return None
 
     def get_django_form(self):
         """returns a django form object based on the params of this action"""
@@ -1362,9 +1361,18 @@ class OpenHelpWindow(Action):
     # icon_name = 'help'
     button_text = '?'
 
-    def get_a_href_target(self):
+    def run_from_ui(self, ar, **kwargs):
+        # print("20210612")
         parts = ['cache', 'help']
         if get_language() != settings.SITE.DEFAULT_LANGUAGE.django_code:
             parts.append(get_language())
-        parts.append("index.html")
-        return settings.SITE.build_media_url(*parts)
+        parts.append(str(ar.actor) + ".html")
+        # parts.append("index.html")
+        ar.success(open_url=settings.SITE.build_media_url(*parts))
+
+    # def get_a_href_target(self):
+    #     parts = ['cache', 'help']
+    #     if get_language() != settings.SITE.DEFAULT_LANGUAGE.django_code:
+    #         parts.append(get_language())
+    #     parts.append("index.html")
+    #     return settings.SITE.build_media_url(*parts)
