@@ -428,22 +428,16 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     allow_delete = True
     hide_headers = False
 
+    toolbar_location = "top"
+    """Not yet implemented.
+    Should be one of 'top' (default), 'bottom', 'right', 'left'
+    """
+
     hide_top_toolbar = False  # 20210509
-    """
-    Have the toolbar at the bottom of the window instead of the top.
-
-    See :ref:`dev.actor_config.hide_top_toolbar`.
-
-    Deprecated. Supported only in :term:`ExtJS front end`.
-    """
+    """See :ref:`dev.actor_config.hide_top_toolbar`."""
 
     hide_navigator = False  # 20210509
-    """
-    Whether to hide navigation functionality.
-
-    See :ref:`dev.actor_config.hide_navigator`.
-
-    """
+    """See :ref:`dev.actor_config.hide_navigator`."""
 
     simple_slavegrid_header = False
 
@@ -710,13 +704,16 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             # subsequent calls, causing tracebacks like "AttributeError:
             # 'TableHandle' object has no attribute 'store'"
             setattr(self, hname, h)
-            try:
+            if False:  # 20210610
                 settings.SITE.kernel.setup_handle(h, ar)
-            except Exception as e:
-                # traceback.print_exc()
-                logger.warning("%s setup_handle failed with %s", self, e)
-                delattr(self, hname)
-                # raise
+            else:
+                try:
+                    settings.SITE.kernel.setup_handle(h, ar)
+                except Exception as e:
+                    # traceback.print_exc()
+                    logger.warning("%s setup_handle failed with %s", self, e)
+                    delattr(self, hname)
+                    # raise
 
         # logger.info("18072017, h:|%s|, h.store:|%s|, #1955"%(h, getattr(h,'store',None)))
         return h
@@ -780,11 +777,11 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         actions.install_layout(cls, 'card_layout', layouts.DetailLayout)
         actions.install_layout(cls, 'item_layout', layouts.DetailLayout)
 
-        cls.extra_layouts = []
+        cls.extra_layouts = dict()
         for name, main in cls.get_extra_layouts():
             layout_instance = actions.resolve_layout(
                 cls, 'extra_layout', main, layouts.DetailLayout)
-            cls.extra_layouts.append(layout_instance)
+            cls.extra_layouts.update({name: layout_instance})
             a = actions.ShowExtraDetail(layout_instance)
             cls._bind_action("extra_"+name, a, False)
             if cls.detail_action is None:
@@ -1593,7 +1590,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
     @classmethod
     def get_extra_layouts(cls):
-        return []
+        return {}
 
     @classmethod
     def get_data_elem(self, name):
