@@ -38,4 +38,6 @@ class Frame(actors.Actor):
 
     @classmethod
     def get_actor_label(self):
-        return self._label or self.default_action.action.label
+        if self.default_action is not None:
+            return self._label or self.default_action.action.label
+        return super(Frame, self).get_actor_label()
