@@ -1,8 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2009-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"Defines the :class:`Model` class.  See :ref:`dev.models`."
+"""Defines the :class:`Model` class.
+
+See :ref:`dev.models`, :doc:`/dev/delete`, :doc:`/dev/disable`,
+:doc:`/dev/hide`, :doc:`/dev/format`
+
+"""
 
 import logging ; logger = logging.getLogger(__name__)
 import copy
@@ -11,7 +16,7 @@ from django.db import models
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.exceptions import FieldDoesNotExist
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.db.models.signals import pre_delete
 from django.utils.text import format_lazy
 
@@ -21,7 +26,6 @@ from lino.core import fields
 from lino.core import signals
 from lino.core import actions
 
-
 from .fields import make_remote_field, RichTextField, displayfield
 from .utils import error2str
 from .utils import obj2str
@@ -30,6 +34,7 @@ from .utils import obj2unicode
 from .utils import class_dict_items
 from .signals import receiver, on_ui_created, pre_ui_delete, pre_ui_save
 from .workflows import ChangeStateAction
+from .tablerequest import TableRequest, sliced_data_iterator
 
 try:
     import bleach
@@ -38,7 +43,6 @@ except ImportError:
 
 
 
-
 class Model(models.Model, fields.TableRow):
     """
     Lino's extension of the plain Django Model class.
@@ -53,122 +57,27 @@ class Model(models.Model, fields.TableRow):
         abstract = True
 
     allow_cascaded_copy = frozenset()
-    """A set of names of `ForeignKey` or `GenericForeignKey` fields of
-    this model that cause objects to be automatically duplicated when
-    their master gets duplicated.
-
-    If this is a simple string, Lino expects it to be a
-    space-separated list of filenames and convert it into a set at
-    startup.
-
-    """
-
     allow_cascaded_delete = frozenset()
-    """A set of names of `ForeignKey` or `GenericForeignKey` fields of
-    this model that allow for cascaded delete.
-
-    Unlike with Dango's `on_delete
-    <https://docs.djangoproject.com/en/3.0/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
-    attribute you control cascaded delete behaviour on the model whose instances
-    are going to be deleted.
-
-    If this is a simple string, Lino expects it to be a
-    space-separated list of filenames and convert it into a set at
-    startup.
-
-    Lino by default forbids to delete any object that is referenced by
-    other objects. Users will get a message of type "Cannot delete X
-    because n Ys refer to it".
-
-    Example: Lino should not refuse to delete a Mail just because it
-    has some Recipient.  When deleting a Mail, Lino should also delete
-    its Recipients.  That's why
-    :class:`lino_xl.lib.outbox.models.Recipient` has
-    ``allow_cascaded_delete = 'mail'``.
-
-    This is also used by :class:`lino.mixins.duplicable.Duplicate` to
-    decide whether slaves of a record being duplicated should be
-    duplicated as well.
-
-    At startup (in :meth:`kernel_startup
-    <lino.core.kernel.Kernel.kernel_startup>`) Lino automatically sets
-    `on_delete
-    <https://docs.djangoproject.com/en/3.0/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
-    to ``PROTECT`` for all FK fields that are not listed in the
-    ``allow_cascaded_delete`` of their model.
-
-    """
 
     grid_post = actions.CreateRow()
     submit_insert = actions.SubmitInsert()
-    """
-    The :class:`SubmitInsert <lino.core.actions.SubmitInsert>` action to be executed when the
-    when the users submits an insert window.
-
-    See :mod:`lino.mixins.dupable` for an example of how to
-    override it.
-
-    """
 
     allow_merge_action = False
-    """Whether this model should have a merge action.
-
-    See :class:`lino.core.merge.MergeAction`
-    """
 
     show_in_site_search = True
-    """Set this to `False` if you really don't want this model to occur
-    in the site-wide search
-    (:class:`lino.modlib.about.SiteSearch`).
-
-    """
 
     quick_search_fields = None
-    """
-    Explicitly specify the fields to be included in queries with a
-    quick search value.
-
-    In your model declarations this should be either `None` or a
-    `string` containing a space-separated list of field names.  During
-    server startup resolves it into a tuple of data elements.
-
-    If it is `None`, Lino installs a list of all CharFields on the
-    model.
-
-    If you want to not inherit this field from a parent using standard
-    MRO, then you must set that field explictly to `None`.
-
-    This is also used when a gridfilter has been set on a foreign key
-    column which points to this model.
-
-    **Special quick search strings**
-
-    If the search string starts with "#", then Lino searches for a row
-    with that *primary key*.
-
-    If the search string starts with "*", then Lino searches for a row
-    with that *reference*.
-    """
 
     quick_search_fields_digit = None
-    """Same as :attr:`quick_search_fields`, but this list is used when the
-    search text contains only digits (and does not start with '0').
-
-    """
 
     active_fields = frozenset()
-    """If specified, this is the default value for
+    """Deprecated. If specified, this is the default value for
     :attr:`active_fields<lino.core.tables.AbstractTable.active_fields>`
     of every `Table` on this model.
 
     """
 
     hidden_elements = frozenset()
-    """If specified, this is the default value for
-    :attr:`hidden_elements<lino.core.tables.AbstractTable.hidden_elements>`
-    of every `Table` on this model.
-
-    """
 
     # simple_parameters = frozenset()
     # """If specified, this is the default value for :attr:`simple_parameters
@@ -178,13 +87,6 @@ class Model(models.Model, fields.TableRow):
     # """
 
     preferred_foreignkey_width = None
-    """The default preferred width (in characters) of widgets that
-    display a ForeignKey to this model.
-
-    If not specified, the default default `preferred_width`
-    for ForeignKey fields is *20*.
-
-    """
 
     workflow_state_field = None
     """If this is set on a Model, then it will be used as default value
@@ -211,11 +113,7 @@ class Model(models.Model, fields.TableRow):
     # """
 
     summary_row_template = None
-    """
-    An optional name of a template to use for :meth:`as_summary_row`.
-    """
 
-    _widget_options = {}
     _lino_tables = []
     _bleached_fields = []
 
@@ -259,6 +157,10 @@ class Model(models.Model, fields.TableRow):
                     #     "Virtual field {}.{} hides {} "
                     #     "of same name.".format(
                     #         full_model_name(model), k, f.__class__.__name__))
+                # if k == "workflow_buttons":
+                #     print("20210306 attach virtual field from {} to {}".format(m, model))
+                # if m is not model or not issubclass(model, Model):
+                #     # don't reuse a virtual field injected to a plain Django model
                 if m is not model:
                     # if k == "municipality" and model.__name__ == "Client":
                     #     print("20200818", m, model)
@@ -293,11 +195,9 @@ class Model(models.Model, fields.TableRow):
             if vf.name == name:
                 return vf
         return getattr(cls, name, None)
-
         # we cannot return super(Model, cls).get_data_elem(name) here because
         # get_data_elem is grafted also to pure Django models which don't
-        # inherit from TableRow
-
+        # inherit from lino.core.Model
 
     def disable_delete(self, ar=None):
         # In case of MTI, every concrete model has its own ddh.
@@ -314,12 +214,6 @@ class Model(models.Model, fields.TableRow):
         return self.__class__._lino_ddh.disable_delete_on_object(self)
 
     def disabled_fields(self, ar):
-        """
-        Return a set of names of fields that should be disabled (not
-        editable) for this record.
-
-        See :doc:`/dev/disabled_fields`.
-        """
         return set()
 
     def delete(self, **kw):
@@ -333,10 +227,6 @@ class Model(models.Model, fields.TableRow):
         super(Model, self).delete(**kw)
 
     def delete_veto_message(self, m, n):
-        """Return the message :message:`Cannot delete X because N Ys refer to
-        it.`
-
-        """
         msg = _(
             "Cannot delete %(model)s %(self)s "
             "because %(count)d %(refs)s refer to it."
@@ -376,10 +266,6 @@ class Model(models.Model, fields.TableRow):
 
     @classmethod
     def hide_elements(self, *names):
-        """Mark the named data elements (fields) as hidden.  They remain in
-        the database but are not visible in the user interface.
-
-        """
         for name in names:
             if self.get_data_elem(name) is None:
                 raise Exception("%s has no element '%s'" % (self, name))
@@ -438,10 +324,6 @@ class Model(models.Model, fields.TableRow):
 
     @classmethod
     def create_from_choice(cls, text):
-        """
-        Called when a learning combo has been submitted.
-        Create a persistent database object if the given text contains enough information.
-        """
         # if cls.disable_create_choice:
         #     return
         values = cls.choice_text_to_dict(text)
@@ -457,10 +339,6 @@ class Model(models.Model, fields.TableRow):
 
     @classmethod
     def choice_text_to_dict(cls, text):
-        """
-        Return a dict of the fields to fill when the given text contains enough
-        information for creating a new database object.
-        """
         return None
 
     @classmethod
@@ -540,32 +418,9 @@ class Model(models.Model, fields.TableRow):
         return flt
 
     def on_create(self, ar):
-        """
-        Override this to set default values that depend on the request.
-
-        The difference with Django's `pre_init
-        <https://docs.djangoproject.com/en/1.11/ref/signals/#pre-init>`__
-        and `post_init
-        <https://docs.djangoproject.com/en/1.11/ref/signals/#post-init>`__
-        signals is that (1) you override the method instead of binding
-        a signal and (2) you get the action request as argument.
-
-        Used e.g. by :class:`lino_xl.lib.notes.Note`.
-        """
         pass
 
     def before_ui_save(self, ar, cw):
-        """A hook for adding custom code to be executed each time an
-        instance of this model gets updated via the user interface and
-        **before** the changes are written to the database.
-
-        Consider using the :data:`pre_ui_save
-        <lino.core.signals.pre_ui_save>` signal instead.
-
-        Example in :class:`lino_xl.lib.cal.Event` to mark the
-        event as user modified by setting a default state.
-
-        """
         for f, old, new in self.fields_to_bleach():
             setattr(self, f.name, new)
 
@@ -593,45 +448,16 @@ class Model(models.Model, fields.TableRow):
 
 
     def after_ui_save(self, ar, cw):
-        """Like :meth:`before_ui_save`, but
-        **after** the changes are written to the database.
-
-        Arguments:
-
-            ar: the action request
-
-            cw: the :class:`ChangeWatcher <lino.core.diff.ChangeWatcher>`
-                object, or `None` if this is a new instance.
-
-        Called after a PUT or POST on this row, and after the row has
-        been saved.
-
-        Used by
-        :class:`lino_welfare.modlib.debts.models.Budget`
-        to fill default entries to a new Budget,
-        or by :class:`lino_welfare.modlib.cbss.models.CBSSRequest`
-        to execute the request,
-        or by
-        :class:`lino_welfare.modlib.jobs.models.Contract`
-        :class:`lino_welfare.modlib.pcsw.models.Coaching`
-        :class:`lino.modlib.vat.models.Vat`.
-        Or :class:`lino_welfare.modlib.households.models.Household`
-        overrides this in order to call its `populate` method.
-
-        """
         # Invalidate disabled_fields cache
         self._disabled_fields = None
 
     def after_ui_create(self, ar):
-        """
-        Hook to define custom behaviour to run when a user has created a new instance
-        of this model.
-        """
         # print(19062017, "Ticket 1910")
         pass
 
     def save_new_instance(elem, ar):
         """Save this instance and fire related behaviour."""
+        # elem.full_clean()
         pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
         elem.before_ui_save(ar, None)
         elem.save(force_insert=True)
@@ -666,16 +492,10 @@ class Model(models.Model, fields.TableRow):
         return ba.get_bound_action_permission(ar, self, state)
 
     def update_owned_instance(self, controllable):
-        """
-        Called by :class:`lino.modlib.gfks.Controllable`.
-        """
         #~ print '20120627 tools.Model.update_owned_instance'
         pass
 
     def after_update_owned_instance(self, controllable):
-        """
-        Called by :class:`lino.modlib.gfks.Controllable`.
-        """
         pass
 
     def get_mailable_recipients(self):
@@ -692,55 +512,10 @@ class Model(models.Model, fields.TableRow):
         """
         return []
 
-    # moved to TableRow
-    # def get_overview_elems(self, ar):
-    #     """This is expected to return a list of HTML elements to be wrapped
-    #     into a `<DIV>`.
-    #
-    #     """
-    #     # return [ar.obj2html(self)]
-    #     return [self.obj2href(ar)]
-
     def on_duplicate(self, ar, master):
-        """
-        Called after duplicating a row on the new row instance.
-
-        Also called recursively on all related objects.  Where "related
-        objects" means those which point to the master using a FK which is
-        listed in :attr:`allow_cascaded_delete
-        <lino.core.model.Model.allow_cascaded_delete>`.
-
-        Called by the :class:`lino.mixins.duplicable.Duplicate` action.
-
-        `ar` is the action request that asked to duplicate.
-
-        If `master` is not None, then this is a cascaded duplicate
-        initiated by a :meth:`duplicate` on the specified `master`.
-
-        Note that this is called *before* saving the object for the
-        first time.
-
-        Obsolete: On the master (i.e. when `master` is `None`), this
-        is called *after* having saved the new object for a first
-        time, and for related objects (`master` is not `None`) it is
-        called *before* saving the object.  But even when an
-        overridden :meth:`on_duplicate` method modifies a master, you
-        don't need to :meth:`save` because Lino checks for
-        modifications and saves the master a second time when needed.
-
-
-        """
         pass
 
     def after_duplicate(self, ar, master):
-        """Called by :class:`lino.mixins.duplicable.Duplicate` on
-        the new copied row instance, after the row and it's related fields
-        have been saved.
-
-        `ar` is the action request that asked to duplicate.
-
-        `ar.selected_rows[0]` contains the original row that is being
-        copied, which is the `master` parameter """
         pass
 
     def before_state_change(self, ar, old, new):
@@ -763,9 +538,11 @@ class Model(models.Model, fields.TableRow):
         target_state.choicelist.before_state_change(row, ar, old, target_state)
         row.before_state_change(ar, old, target_state)
         setattr(row, state_field.attname, target_state)
-        row.save()
+        # row.save()
         target_state.choicelist.after_state_change(row, ar, old, target_state)
         row.after_state_change(ar, old, target_state)
+        # row.full_clean()
+        row.save()
         watcher.send_update(ar)
         row.after_ui_save(ar, watcher)
 
@@ -778,18 +555,6 @@ class Model(models.Model, fields.TableRow):
         pass
 
     def as_summary_row(self, ar):
-        """
-        Return a raw HTML string representing this object in a data view as a
-        single paragraph.
-
-        The string should represent a single ``<p>``.
-
-        If :attr:`summary_row_template` is set, this will render this object
-        using the named template, otherwise it will call :meth:`summary_row` and
-        wrap the result into a paragraph.
-
-
-        """
         if self.summary_row_template:
             # not tested
             env = settings.SITE.plugins.jinja.renderer.jinja_env
@@ -799,36 +564,9 @@ class Model(models.Model, fields.TableRow):
         return tostring(E.p(*self.summary_row(ar)))
 
     def summary_row(self, ar, **kw):
-        """
-        Yield a sequence of ElementTree elements that represent this database
-        object in a summary panel.
-
-        The elements will be wrapped into a `<p>` by :meth:`as_summary_row`.
-
-        The default representation is the text returned by :meth:`__str__` in a
-        link that opens the detail view on this database object.
-
-        The description may vary depending on the given action request.
-
-        For example a partner model of a given application may want to always
-        show the city of a partner unless city is among the known values::
-
-            def summary_row(self, ar):
-                elems = [ar.obj2html(self)]
-                if self.city and not ar.is_obvious_field("city"):
-                    elems += [" (", ar.obj2html(self.city), ")"]
-                return elems
-
-        Note that this is called by the class method of same name on
-        :class:`lino.core.actors.Actor`, which may be customized and may decide
-        to not call the model method.
-
-        TODO: rename this to `row2summary` and write documentation.
-
-        """
         yield ar.obj2html(self)
 
-    @fields.displayfield(_("Name"), max_length=15)
+    @displayfield(_("Name"), max_length=15)
     def name_column(self, ar):
         return str(self)
 
@@ -841,17 +579,43 @@ class Model(models.Model, fields.TableRow):
     # def get_mobile_list_item_elems(self, ar):
     #     return [self.obj2href(ar)]
 
-    # @fields.displayfield(_("Description"))
-    # @fields.htmlbox(_("Overview"))
     @fields.htmlbox()
-    def overview(self, ar):
-        if ar is None:
-            return ''
-        return E.div(*forcetext(self.get_overview_elems(ar)))
+    def navigation_panel(self, ar):
+        if not isinstance(ar, TableRequest):
+            return None
+        items = []
+        navinfo = ar.actor.get_navinfo(ar, self)
+        if navinfo is None:
+            return None
+        nav_items = [
+            ar.goto_pk(navinfo['first'], "⏮ "), # 23EE
+            ar.goto_pk(navinfo['prev_page'], "⏪ "), # 23Ea
+            ar.goto_pk(navinfo['prev'], "◀ "),  # 25C0
+            navinfo['message'],
+            ar.goto_pk(navinfo['next'], " ▶"),  # 25B6
+            ar.goto_pk(navinfo['next_page'], " ⏩"), # 23E9
+            ar.goto_pk(navinfo['last'], " ⏭") # 0x23ED
+            ]
+        items.append(E.p(*nav_items))
+        # print("20210325", navinfo)
+        # raise Exception("20")
 
-    @fields.displayfield(_("Workflow"), help_text="List of actions that change the workflow state of this object.")
+        qs = sliced_data_iterator(ar.data_iterator, navinfo['offset'], ar.limit)
+        for obj in qs:
+            if obj.pk == self.pk:
+                items.append(E.b(str(obj)))
+            else:
+                items.append(ar.obj2html(obj))
+        # return E.ul(*items, **{'class': 'layout-wrapper layout-sidebar'})
+        # return E.div(*items, **{'class': 'l-component'})
+        # items = join_elems([E.p(i) for i in items])
+        items = join_elems(items, sep=E.br)
+        kwargs = {'class': 'list-item', 'style': 'width:15em;'}
+        return ar.html_text(E.div(*items, **kwargs))
+
+
+    @displayfield(_("Workflow"), help_text="List of actions that change the workflow state of this object.")
     def workflow_buttons(self, ar):
-
         if ar is None:
             return ''
         return self.get_workflow_buttons(ar)
@@ -939,42 +703,6 @@ class Model(models.Model, fields.TableRow):
         #     print("20200425 Model.get_chooser_for_field", cls, fieldname, d)
         return d.get(fieldname, None)
 
-    @classmethod
-    def set_widget_options(self, name, **options):
-        """
-        Set default values for the widget options of a given element.
-
-        Usage example::
-
-            JobSupplyment.set_widget_options('duration', width=10)
-
-        has the same effect as specifying ``duration:10`` each time
-        when using this element in a layout.
-
-        List of widget options that can be set:
-
-        `width`
-        `preferred_width`
-        `label`
-        `editable`
-        `preferred_height`
-        `hide_sum`
-
-
-        """
-        # from lino.modlib.extjs.elems import FieldElement
-        # for k in options.keys():
-        #     if not hasattr(FieldElement, k):
-        #         raise Exception("Invalid widget option {}".format(k))
-        self._widget_options = dict(**self._widget_options)
-        d = self._widget_options.setdefault(name, {})
-        d.update(options)
-
-    @classmethod
-    def get_widget_options(self, name, **options):
-        options.update(self._widget_options.get(name, {}))
-        return options
-
     def filename_root(self):
         return self._meta.app_label + '.' + self.__class__.__name__ \
             + '-' + str(self.pk)
@@ -1036,16 +764,6 @@ class Model(models.Model, fields.TableRow):
 
         """
 
-    @classmethod
-    def get_layout_aliases(cls):
-        """
-
-        Yield a series of (ALIAS, repl) tuples that cause a name ALIAS in a
-        layout based on this model to be replaced by its replacement `repl`.
-
-        """
-        return []
-
     @classmethod
     def add_picker(model, fldname):
         """Add a picker for the named choicelist field.
@@ -1112,9 +830,8 @@ class Model(models.Model, fields.TableRow):
     @classmethod
     def django2lino(cls, model):
         """
-        Injects additional methods into a pure Django model that does
-        not inherit from :class:`lino.core.model.Model`.  Used by
-        :mod:`lino.core.kernel`
+        Inject Lino model methods into a pure Django model that does
+        not inherit from :class:`lino.core.model.Model`.
 
         """
         wo = {}
@@ -1126,6 +843,8 @@ class Model(models.Model, fields.TableRow):
         if issubclass(model, cls):
             return
 
+        # print("20210306 djago2lino", cls, model)
+
         for k in LINO_MODEL_ATTRIBS:
             if not hasattr(model, k):
                 #~ setattr(model,k,getattr(dd.Model,k))
@@ -1196,6 +915,8 @@ class Model(models.Model, fields.TableRow):
 LINO_MODEL_ATTRIBS = (
     'collect_virtual_fields',
     'define_action',
+    'get_workflow_buttons',
+    'workflow_buttons',
     'delete_instance',
     'setup_parameters',
     'add_param_filter',
@@ -1270,7 +991,7 @@ def pre_delete_handler(sender, instance=None, **kw):
     <https://docs.djangoproject.com/en/1.11/ref/contrib/contenttypes/#django.contrib.contenttypes.fields.GenericRelation>`_
     field (according to `Why won't my GenericForeignKey cascade
     when deleting?
-    <http://stackoverflow.com/questions/6803018/why-wont-my-genericforeignkey-cascade-when-deleting>`_).
+    <https://stackoverflow.com/questions/6803018/why-wont-my-genericforeignkey-cascade-when-deleting>`_).
     OTOH this statement seems to be wrong: it happens also in my
     projects which do *not* use any `GenericRelation`.  As
     :mod:`test_broken_gfk
