@@ -170,6 +170,10 @@ class Plugin(object):
 
     """
 
+    support_async = False
+    """Whether this plugin supports usage of :class:`lino.utils.AsynchronousValue`."""
+
+
     renderer = None
     """The renderer used by this plugin. See :doc:`/dev/rendering`."""
 
