@@ -91,7 +91,7 @@ class JsCacheRenderer():
         self.action_param_panels = set()
         self.other_panels = set()
 
-        def add(res, collector, fl, formpanel_name):
+        def add(res, collector, fl, formpanel_name, choice_name=None):
             # res: an actor class or action instance
             # collector: one of form_panels, param_panels or
             # action_param_panels
@@ -131,6 +131,8 @@ class JsCacheRenderer():
             if fl not in collector:
                 fl._formpanel_name = formpanel_name
                 fl._url = res.actor_url()
+                if choice_name:
+                    fl.choice_name = choice_name
                 collector.add(fl)
                 # if str(res) == 'courses.Pupils':
                 #     print("20160329 ext_renderer.py collected {}".format(fl))
@@ -138,9 +140,9 @@ class JsCacheRenderer():
         for res in self.actors_list:
             add(res, self.form_panels, res.detail_layout,
                 "%s.DetailFormPanel" % res)
-            for i, fl in enumerate(res.extra_layouts):
+            for name, fl in res.extra_layouts.items():
                 add(res, self.form_panels, fl,
-                    "{}._{}_DetailFormPanel".format(res, i))
+                    "{}._{}_DetailFormPanel".format(res, name), name)
             add(res, self.form_panels, res.insert_layout,
                 "%s.InsertFormPanel" % res)
             # if res.parameters is not None:
