@@ -24,6 +24,7 @@ from etgen.html import E, tostring, iselement
 from lino.core.auth.utils import AnonymousUser
 
 from lino.core import callbacks
+from lino.core import actions
 
 from .boundaction import BoundAction
 from .signals import on_ui_created, pre_ui_save
@@ -902,11 +903,17 @@ class BaseRequest(object):
                 return ar.renderer.show_story(
                     self, story, header_level=header_level,
                     header_links=header_links, stripped=stripped)
-            return ar.renderer.show_table(
-                ar, column_names=column_names, header_level=header_level,
-                header_links=header_links,
-                nosummary=nosummary, stripped=stripped,
-                show_links=show_links, display_mode=display_mode)
+            elif isinstance(ar.bound_action.action, actions.ShowTable):
+                return ar.renderer.show_table(
+                    ar, column_names=column_names, header_level=header_level,
+                    header_links=header_links,
+                    nosummary=nosummary, stripped=stripped,
+                    show_links=show_links, display_mode=display_mode)
+            elif isinstance(ar.bound_action.action, actions.ShowDetail):
+                return ar.renderer.show_detail(ar)
+            else:
+                print("Cannot show", ar.bound_action.action)
+
 
         if language:
             with translation.override(language):
@@ -1149,6 +1156,7 @@ class BaseRequest(object):
         rh = ar.ah
         rec = ar.elem2rec1(rh, elem, None, **rec)
         if ar.actor.hide_top_toolbar or ar.bound_action.action.hide_top_toolbar:
+            # TODO: above test is suspicious. To be observed.
             rec.update(title=ar.get_detail_title(elem))
         else:
             rec.update(title=ar.get_breadcrumbs(elem))
