@@ -50,6 +50,7 @@ from lino.utils import iif
 from lino.utils.format_date import fds
 from lino.core.requests import PhantomRow
 from lino.utils import IncompleteDate
+from lino.utils import AsynchronousValue
 
 
 class StoreField(object):
@@ -79,10 +80,18 @@ class StoreField(object):
     list_values_count = 1
     "Necessary to compute :attr:`Store.pk_index`."
 
+    asynchronous = False
+
     def __init__(self, field, name, **options):
         self.field = field
         self.name = str(name)  # TypeError 20160425
         self.options = options
+        # if settings.SITE.kernel.default_ui.support_async:
+        if settings.SITE.default_ui == "lino_react.react":
+            if isinstance(field, fields.FakeField) and field.asynchronous:
+                self.asynchronous = True
+                self.asynchronous = False  # wip
+                # print("20210610 asynchronous", name)
 
     def as_js(self, name):
         """
@@ -110,6 +119,7 @@ class StoreField(object):
     def full_value_from_object(self, obj, ar=None):
         return self.field.value_from_object(obj)
 
+
     def value2list(self, ar, v, l, row):
         return l.append(v)
 
@@ -592,7 +602,7 @@ class DisabledFieldsStoreField(SpecialStoreField):
         # return
 
 class RowClassStoreField(SpecialStoreField):
-    name = str('row_class')
+    name = 'row_class'
 
     def full_value_from_object(self, obj, ar=None):
         return ' '.join([ar.renderer.row_classes_map.get(s, '')
@@ -1117,7 +1127,7 @@ class Store(BaseStore):
             dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
             self.collect_fields(self.detail_fields, dh)
 
-        for form in rh.actor.extra_layouts:
+        for form in rh.actor.extra_layouts.values():
             dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
             self.collect_fields(self.detail_fields, dh)
 
@@ -1299,7 +1309,10 @@ class Store(BaseStore):
                 fld.value2list(ar, None, l, row)
         else:
             for fld in self.list_fields:
-                v = fld.full_value_from_object(row, ar)
+                if fld.asynchronous:
+                    v = AsynchronousValue(fld, row)
+                else:
+                    v = fld.full_value_from_object(row, ar)
                 fld.value2list(ar, v, l, row)
         # logger.info("20130611 Store row2list() --> %r", l)
         return l
@@ -1313,7 +1326,10 @@ class Store(BaseStore):
             if fld is None:
                 continue
             # logger.info("20140429 Store.row2dict %s", fld)
-            v = fld.full_value_from_object(row, ar)
+            if fld.asynchronous:
+                v = AsynchronousValue(fld, row)
+            else:
+                v = fld.full_value_from_object(row, ar)
             fld.value2dict(ar, fld.name, v, d, row)
             # logger.info("20140429 Store.row2dict %s -> %s", fld, v)
         #     if "households_" in fld.name:
