@@ -699,6 +699,9 @@ class VentilatingTable(VentilatedColumns):
 class ButtonsTable(VirtualTable):
     """
 
+    Probably deprecated. Might not work as expected in React (because of
+    hide_top_toolbar).
+
     An abstract :class:`VirtualTable` with only one column and whose rows are
     action buttons.
 
