@@ -1,5 +1,5 @@
 # Copyright 2009-2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """The default URLconf module for Lino applications.
 As an application developer you don't need to worry about this.
@@ -10,7 +10,8 @@ This is found by Django because :mod:`lino.projects.std.settings`
 """
 
 from django.conf import settings
-from django.conf.urls import url, include
+from django.urls import re_path as url
+from django.conf.urls import include
 from django.conf.urls.static import static
 from lino.core.utils import is_devserver
 
@@ -43,8 +44,8 @@ for p in site.installed_plugins:
 if site.social_auth_backends:
     urlpatterns.append(
         url('^oauth/', include('social_django.urls', namespace='social')))
-        
-        
+
+
 
 if site.django_admin_prefix:  # not tested
     from django.contrib import admin
@@ -73,3 +74,5 @@ if is_devserver():
 
     # pat = r'^{0}(?P<path>.*)$'.format(settings.STATIC_URL[1:])
     # urlpatterns.append(url(pat, serve))
+
+# print("20210114", urlpatterns)
