@@ -1,5 +1,5 @@
 # Copyright 2010-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Utility functions used by :mod:`lino.modlib.extjs.views`.
 
 """
@@ -29,7 +29,7 @@ def json_response(x, content_type='application/json', status=200):
             raise Exception("Failed to render {!r} : {}".format(x, e))
 
     # Theroretically we should send content_type='application/json'
-    # (http://stackoverflow.com/questions/477816/the-right-json-content-type),
+    # (https://stackoverflow.com/questions/477816/the-right-json-content-type),
     # but "File uploads are not performed using Ajax submission, that
     # is they are not performed using XMLHttpRequests. (...)  If the
     # server is using JSON to send the return object, then the
@@ -72,16 +72,20 @@ def action_request(app_label, actor, request, rqdata, is_list, **kw):
     # print(20160329, rqdata.keys())
     rpt = requested_actor(app_label, actor)
     action_name = rqdata.get(constants.URL_PARAM_ACTION_NAME, None)
+    a = None
     if not action_name:
+        # print("20210215", rqdata)
         if is_list:
             action_name = rpt.default_list_action_name
         else:
-            action_name = rpt.default_elem_action_name
-    a = rpt.get_url_action(action_name)
+            a = rpt.detail_action
+            # action_name = rpt.default_elem_action_name
     if a is None:
-        raise http.Http404(
-            "%s has no url action %r (possible values are %s)" % (
-                rpt, action_name, rpt.get_url_action_names()))
+        a = rpt.get_url_action(action_name)
+        if a is None:
+            raise http.Http404(
+                "%s has no url action %r (possible values are %s)" % (
+                    rpt, action_name, rpt.get_url_action_names()))
     user = request.subst_user or request.user
     if True:  # False:  # 20130829
         if not a.get_view_permission(user.user_type):
@@ -93,7 +97,7 @@ def action_request(app_label, actor, request, rqdata, is_list, **kw):
                 # internationalized because some error handling code
                 # may want to write it to a plain ascii stream.
     ar = rpt.request(request=request, action=a, rqdata=rqdata, **kw)
-    # print("20200901", ar, rqdata)
+    # print("20210403b", a.action.__class__, rqdata)
     return ar
 
 
