@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2012-2013 Luc Saffre
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Writes screenshots to <project_dir>/media/cache/screenshots
@@ -24,9 +24,9 @@ from os.path import join
 from multiprocessing import Process
 
 from django.db import models
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.utils import translation
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
 from django.core.servers.basehttp import get_internal_wsgi_application
@@ -156,7 +156,7 @@ class Command(BaseCommand):
 
         # Igor Katson writes an interesting answer in
         # `Django Broken pipe in Debug mode
-        # <http://stackoverflow.com/questions/7912672/django-broken-pipe-in-debug-mode>`__::
+        # <https://stackoverflow.com/questions/7912672/django-broken-pipe-in-debug-mode>`__::
         # Monkeypatch python not to print "Broken Pipe" errors to stdout.
         import socketserver
         from wsgiref import handlers
