@@ -1,5 +1,5 @@
-# Copyright 2014-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2014-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Defines classes related to date ranges.
@@ -14,7 +14,7 @@ except ImportError:
 
 from django.db import models
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
 from django.core.exceptions import ValidationError
 from django.utils.timezone import is_aware
@@ -202,7 +202,7 @@ class DateRange(DateRangeObservable):
     date fields.
 
     Designed for usage with
-    :class:`lino.modlib.system.choicelists.PeriodEvents`.
+    :class:`lino.modlib.system.PeriodEvents`.
     """
 
     class Meta(object):
@@ -341,7 +341,7 @@ class Weekly(ObservedDateRange):
 
 class Today(ParameterPanel):
     """A :class:`ParameterPanel <lino.core.param_panel.ParameterPanel>`
-    with a field `today` which defaults to today.
+    with a field `today` that defaults to today.
 
     """
     def __init__(self, verbose_name=_("Situation on"), **kw):
