@@ -1,5 +1,5 @@
 # Copyright 2008-2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 See :doc:`/specs/about`.
@@ -16,5 +16,5 @@ class Plugin(ad.Plugin):
         m.add_action(site.models.about.About)
         # m.add_action(site.models.about.SiteSearch)
 
-    def get_quicklinks(site, user):
+    def get_quicklinks(site):
         yield 'about.SiteSearch'
