@@ -1,5 +1,5 @@
 # Copyright 2012-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Database models for this plugin.
 
@@ -18,7 +18,7 @@ import datetime
 from django.conf import settings
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils import timezone
 
 from lino.api import dd
@@ -63,12 +63,12 @@ class Change(dd.Model):
     .. attribute:: master
 
         The database object which acts as "master".
-    
+
     .. attribute:: object
 
         The database object which has been modified.
-    
-    
+
+
     """
 
     class Meta(object):
@@ -293,4 +293,3 @@ def on_merge(sender=None, request=None, **kw):
         return
     log_change(ChangeTypes.merge, request,
                master, sender.obj, sender.logmsg())
-
