@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino.api import dd, rt, _
 from datetime import datetime
@@ -16,15 +16,17 @@ class Emotions(dd.ChoiceList):
 
 # ⁈:2048  👍:1F44D  👎:1F44E  ✅:2705  ❎:274e  😠:1F620 😀:1F600 😐:1f610
 add = Emotions.add_item
-add('ok', _("Okay"), 'ok')
-# add('but', _("But"), 'but', button_text="⁈")
-add('agree', _("Agree"), 'agree', button_text="✅")
-add('disagree', _("Disagree"), 'disagree', button_text="❎")
-# add('like', _("Like"), 'like', button_text="👍")
-# add('dislike', _("Dislike"), 'dislike', button_text="👎")
-# add('happy', _("Happy"), 'happy', button_text="😀")
-# add('angry', _("Angry"), 'angry', button_text="😠")
-# add('skeptical', _("Skeptical"), 'skeptical', button_text="😐")
+if dd.plugins.comments.emotion_range == "business":
+    add('ok', _("Okay"), 'ok')
+    # add('but', _("But"), 'but', button_text="⁈")
+    add('agree', _("Agree"), 'agree', button_text="✅")
+    add('disagree', _("Disagree"), 'disagree', button_text="❎")
+elif dd.plugins.comments.emotion_range == "social":
+    add('ok', _("Like"), 'ok', button_text="👍")
+    add('dislike', _("Dislike"), 'dislike', button_text="👎")
+    add('happy', _("Happy"), 'happy', button_text="😀")
+    add('angry', _("Angry"), 'angry', button_text="😠")
+    add('skeptical', _("Skeptical"), 'skeptical', button_text="😐")
 
 
 class ObservedTime(ObservedEvent):
@@ -49,8 +51,6 @@ class CommentEvents(dd.ChoiceList):
     verbose_name = _("Observed event")
     verbose_name_plural = _("Observed events")
 
-
-
 def add(*args):
     CommentEvents.add_item_instance(ObservedTime(*args))
 add('10', 'created', _("Created"))
