@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2013-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.utils.translation import ngettext
 from django.contrib.humanize.templatetags.humanize import naturaltime
@@ -9,7 +9,6 @@ from django.db import models
 from lino.api import dd, rt, gettext, _
 from lino.modlib.users.mixins import My
 from etgen.html import E, tostring
-# from lxml import etree
 import lxml
 # from lino.utils.soup import truncate_comment
 from lino import mixins
@@ -19,6 +18,7 @@ from lino.core.gfks import gfk2lookup
 from .roles import CommentsReader, CommentsUser, CommentsStaff
 from .choicelists import CommentEvents, Emotions
 from .fields import MyEmotionField
+from .mixins import Commentable
 
 
 class CommentTypes(dd.Table):
@@ -48,7 +48,7 @@ class CommentDetail(dd.DetailLayout):
     general1 = """
     owner private
     reply_to pick_my_emotion
-    full_preview
+    body_full_preview
     """
     # general2 = """
     # RepliesByComment
@@ -81,6 +81,13 @@ class Comments(dd.Table):
 
     detail_layout = "comments.CommentDetail"
 
+    card_layout = dd.Panel("""
+    reply_to owner owner_type owner_id
+    # comment_type
+    body
+    private
+    """, label=_("Cards"))
+
     # html_parser = etree.HTMLParser()
 
     # ~ column_names = "id date user type event_type subject * body_html"
@@ -141,8 +148,8 @@ class Comments(dd.Table):
 
     # @classmethod
     # def as_li(cls, self, ar):
-    #     # chunks = [ar.parse_memo(self.short_preview)]
-    #     chunks = [self.short_preview]
+    #     # chunks = [ar.parse_memo(self.body_short_preview)]
+    #     chunks = [self.body_short_preview]
     #
     #     by = _("{0} by {1}").format(
     #         naturaltime(self.created), str(self.user))
@@ -177,7 +184,7 @@ class MyComments(My, Comments):
     required_roles = dd.login_required(CommentsUser)
     auto_fit_column_widths = True
     order_by = ["-modified"]
-    column_names = "id modified short_preview owner workflow_buttons *"
+    column_names = "id modified body_short_preview owner workflow_buttons *"
 
 
 class AllComments(Comments):
@@ -215,35 +222,39 @@ class CommentsByX(Comments):
         sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
         elems = []
 
-
-        if cls.insert_action is not None and isinstance(obj, cls.model):
-
+        if cls.insert_action is not None:
+            if not cls.editable:
+                raise Exception("20210515 {}", cls)
             ir = cls.insert_action.request_from(sar)
-            # print(20170217, sar)
-            # sar.known_values = dict(
-            #     reply_to=comment, **gfk2lookup(
-            #         comment.__class__.owner, comment.owner))
-            # if ar.get_user().is_authenticated:
+            if cls is not ir.actor:
+                raise Exception("20210515b {}", cls)
             if ir.get_permission():
-                # ir.known_values.update(emotion=emo)
-                ir.known_values.update(reply_to=obj)
-                # **gfk2lookup(obj.__class__.owner, obj.owner)
-                ir.clear_cached_status()
-                btn = ir.ar2button(None, _(" Reply "), icon_name=None)
-                # btn.set("style", "padding-left:10px")
-                elems += [" [", btn, "]"]
-
-            # if ir.get_permission():
-            #     chunks = [gettext("Write new comment:"), " "]
-            #     for i, emo in enumerate(Emotions.get_list_items()):
-            #         if i:
-            #             chunks.append(" | ")
-            #         ir.known_values.update(emotion=emo)
-            #         ir.clear_cached_status()
-            #         chunks.append(ir.ar2button(
-            #             None, emo.button_text or emo.text, icon_name=None,
-            #             title=str(emo.text)))
-            #     elems.append(E.p(*chunks))
+                if isinstance(obj, cls.model):
+                    # we are showing the replies to another comment
+                    ir.known_values.update(reply_to=obj)
+                    ir.known_values.update(owner=obj.owner)
+                    # **gfk2lookup(obj.__class__.owner, obj.owner)
+                    ir.clear_cached_status()
+                    # btn = ir.ar2button(None, _(" Reply "), icon_name=None)
+                    btn = ir.ar2button(None,
+                        title=_("Reply to {} about {}").format(
+                            obj, obj.owner))
+                    # btn.set("style", "padding-left:10px")
+                    elems.append(E.p(btn))
+                    # elems += [" [", btn, "]"]
+                elif isinstance(obj, Commentable):
+                    # we are showing the comment about a Commentable
+                    btn = ir.ar2button(
+                        None, title=_("Start a new {} about {}").format(
+                            cls.model._meta.verbose_name, obj))
+                    # btn = ir.ar2button(
+                    #         None, _("Write new comment:"), # icon_name=None,
+                    #         title=_("Start a new comment about {}").format(obj))
+                    elems.append(E.p(btn))
+                    # elems += [" [", btn, "]"]
+                else:
+                    # this should never happen...
+                    pass
 
         n = 0
         for com in sar.data_iterator:
@@ -253,7 +264,7 @@ class CommentsByX(Comments):
                 break
             elems.append(E.p(*cls.summary_row(sar, com)))
 
-        return E.div(*elems)
+        return ar.html_text(E.div(*elems))
 
     @classmethod
     def summary_row(cls, ar, o, **kw):
@@ -308,7 +319,7 @@ class CommentsByX(Comments):
                     if group and group.ref:
                          yield "@" + group.ref
 
-        if o.num_reactions:
+        if False and o.num_reactions:
             txt = ngettext("{} reaction", "{} reactions", o.num_reactions).format(o.num_reactions)
             yield " ({})".format(txt)
 
@@ -317,16 +328,16 @@ class CommentsByX(Comments):
             txt = ngettext("{} reply", "{} replies", o.num_replies).format(o.num_replies)
             yield " ({})".format(txt)
 
-        if o.short_preview:
+        if o.body_short_preview:
             yield " : "
             try:
-                # el = etree.fromstring(o.short_preview, parser=html_parser)
-                for e in lxml.html.fragments_fromstring(o.short_preview): #, parser=cls.html_parser)
+                # el = etree.fromstring(o.body_short_preview, parser=html_parser)
+                for e in lxml.html.fragments_fromstring(o.body_short_preview): #, parser=cls.html_parser)
                     yield e
-                # el = etree.fromstring("<div>{}</div>".format(o.full_preview), parser=cls.html_parser)
+                # el = etree.fromstring("<div>{}</div>".format(o.body_full_preview), parser=cls.html_parser)
                 # print(20190926, tostring(el))
             except Exception as e:
-                yield "{} [{}]".format(o.short_preview, e)
+                yield "{} [{}]".format(o.body_short_preview, e)
 
 
 # class MyPendingComments(MyComments):
@@ -342,7 +353,7 @@ class CommentsByX(Comments):
 class RecentComments(CommentsByX):
     required_roles = dd.login_required(CommentsReader)
     # required_roles = set([CommentsReader])
-    column_names = "short_preview modified user owner *"
+    column_names = "body_short_preview modified user owner *"
     stay_in_grid = True
     # order_by = ["-modified"]
     label = _("Recent comments")
