@@ -34,6 +34,7 @@ from lino.core import tables
 from lino.utils import AttrDict
 from lino.core import choicelists
 from lino.core import menus
+from lino.core.requests import BaseRequest
 # from lino.core import auth
 from lino.utils import jsgen
 from lino.utils.jsgen import py2js, js_code
@@ -444,7 +445,9 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             items=dashboard,
         )
         if not on_ready:
-            html = site.get_main_html(request, front_end=self.front_end)
+            ar = BaseRequest(request, renderer=self)
+            # html = site.get_main_html(ar, front_end=self.front_end)
+            html = site.get_main_html(ar)
             html = self.html_text(html)
             dashboard.update(html=html)
 
@@ -1115,7 +1118,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         dtl = ba.get_window_layout()
         if dtl is None:
             raise Exception("20210530")
-            for dtl in rpt.extra_layouts:
+            for dtl in rpt.extra_layouts.values():
                 for ln in doit(dtl):
                     yield ln
         else:
@@ -1335,7 +1338,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         for ln in doit(wl, ba.get_window_size()):
             yield ln
 
-        for xwl in ba.actor.extra_layouts:
+        for xwl in ba.actor.extra_layouts.values():
             for ln in doit(xwl, xwl.window_size):
                 yield ln
 
