@@ -155,13 +155,15 @@ class MainHtml(View):
         # ~ logger.info("20130719 MainHtml")
         settings.SITE.startup()
         # ~ raise Exception("20131023")
-        ar = BaseRequest(request)
-        html = settings.SITE.get_main_html(
-            request, front_end=settings.SITE.plugins.extjs)
-        html = settings.SITE.plugins.extjs.renderer.html_text(html)
+        front_end = settings.SITE.plugins.extjs
+        ar = BaseRequest(request, renderer=front_end.renderer)
+            # renderer=settings.SITE.kernel.default_renderer)
+        html = settings.SITE.get_main_html(ar, front_end=front_end)
+        html = front_end.renderer.html_text(html)
         ar.success(html=html)
         ar.set_response(**test_version_mismatch(request))
-        return settings.SITE.kernel.default_renderer.render_action_response(ar)
+        # return settings.SITE.kernel.default_renderer.render_action_response(ar)
+        return front_end.renderer.render_action_response(ar)
 
 
 class SWView(TemplateView):
