@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2006-2019 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """See introduction in :doc:`/dev/memo`.
 
@@ -56,11 +56,22 @@ class Suggester(object):
     def get_suggestions(self, query=''):
         flt = self.data.model.quick_search_filter(query)
         for obj in self.data.filter(flt)[:5]:
-            yield (getattr(obj, self.fldname), self.formatter(obj))
+            yield {'value': getattr(obj, self.fldname), 'title': self.formatter(obj), 'link': self.get_href(obj)}
 
     def get_object(self, abbr):
         return self.getter(abbr)
 
+    def get_href(self, obj, ar=None):
+        an = obj.get_detail_action(ar)
+        return r"javascript:window.App.runAction({" + \
+            f"'actorId': '{self.formatter(an.actor)}', " + \
+            "'an': 'detail', " + \
+            "'rp': null, " + \
+            r"'status': {" + \
+                f"'record_id': {self.formatter(obj.pk)}" + \
+            r"}" + \
+        r"})"
+
 
 class Parser(object):
     """The memo parser.
