@@ -180,7 +180,7 @@ class Dashboard(EmptyTable):
 
     @dd.htmlbox()
     def welcome_messages(cls, obj, ar=None):
-        return settings.SITE.get_main_html(ar.request)
+        return settings.SITE.get_main_html(ar)
         # if ar.get_user().is_authenticated:
         #     return E.p(*settings.SITE.get_welcome_messages(ar))
 
