@@ -1,14 +1,20 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2008-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import os
+from os.path import join, exists
+import glob
+from pathlib import Path
 
 from django.db import models
+from django.db.models.fields.files import FieldFile
 from django.conf import settings
 from django.utils.text import format_lazy
 # from lino.api import string_concat
 from django.utils.translation import pgettext_lazy as pgettext
+from django.template.defaultfilters import filesizeformat
+from django.core.exceptions import ValidationError
 
 from etgen.html import E, join_elems, tostring
 from lino.api import dd, rt, _
@@ -18,11 +24,18 @@ from lino.modlib.gfks.mixins import Controllable
 from lino.modlib.users.mixins import UserAuthored, My
 from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
 from lino.mixins import Referrable
+from lino.modlib.checkdata.choicelists import Checker
 
 from .choicelists import Shortcuts, UploadAreas
-from .mixins import UploadController
+from .mixins import UploadController, UploadBase
 
 
+def filename_leaf(name):
+    i = name.rfind('/')
+    if i != -1:
+        return name[i + 1:]
+    return name
+
 
 class Volume(Referrable):
 
@@ -66,7 +79,7 @@ class UploadType(mixins.BabelNamed):
         #     "\n",
         #     _("-1 means no limit.")))
         help_text=format_lazy(
-            u"{}\n{}",
+            "{}\n{}",
             _("No need to upload more uploads than N of this type."),
             _("-1 means no limit.")))
     wanted = models.BooleanField(
@@ -76,6 +89,119 @@ class UploadType(mixins.BabelNamed):
     shortcut = Shortcuts.field(blank=True)
 
 
+class Upload(UploadBase, UserAuthored, Controllable):
+
+    class Meta(object):
+        abstract = dd.is_abstract_model(__name__, 'Upload')
+        verbose_name = _("Upload file")
+        verbose_name_plural = _("Upload files")
+
+    upload_area = UploadAreas.field(default='general')
+    type = dd.ForeignKey("uploads.UploadType", blank=True, null=True)
+    volume = dd.ForeignKey("uploads.Volume", blank=True, null=True)
+    library_file = models.CharField(_("Library file"), max_length=255, blank=True)
+
+    description = models.CharField(
+        _("Description"), max_length=200, blank=True)
+
+    def __str__(self):
+        if self.description:
+            s = self.description
+        elif self.file:
+            s = filename_leaf(self.file.name)
+        elif self.library_file:
+            s = "{}:{}".format(self.volume.ref, self.library_file)
+        else:
+            s = str(self.id)
+        if self.type:
+            s = str(self.type) + ' ' + s
+        return s
+
+    @dd.displayfield(_("Description"))
+    def description_link(self, ar):
+        s = str(self)
+        if ar is None:
+            return s
+        return self.get_file_button(s)
+
+    @dd.chooser(simple_values=True)
+    def library_file_choices(self, volume):
+        if volume is None:
+            return []
+        return list(volume.get_filenames())
+
+    @dd.chooser()
+    def type_choices(self, upload_area):
+        M = dd.resolve_model('uploads.UploadType')
+        # logger.info("20140430 type_choices %s", upload_area)
+        if upload_area is None:
+            return M.objects.all()
+        return M.objects.filter(upload_area=upload_area)
+
+    def full_clean(self, *args, **kw):
+        super(Upload, self).full_clean(*args, **kw)
+        if self.type is not None:
+            self.upload_area = self.type.upload_area
+
+dd.update_field(Upload, 'user', verbose_name=_("Uploaded by"))
+
+
+class UploadChecker(Checker):
+    verbose_name = _("Check metadata of upload files")
+    model = Upload
+
+    def get_checkdata_problems(self, obj, fix=False):
+        if obj.file:
+            if not exists(join(settings.MEDIA_ROOT, obj.file.name)):
+                yield (False, format_lazy(
+                    _("Upload entry {} has no file"), obj.file.name))
+                return
+
+        file_size = obj.get_real_file_size()
+
+        if obj.file_size != file_size:
+            tpl = "Stored file size {} differs from real file size {}"
+            yield (False, format_lazy(tpl, obj.file_size, file_size))
+
+UploadChecker.activate()
+
+
+class UploadsFolderChecker(Checker):
+    verbose_name = _("Find orphaned files in uploads folder")
+
+    def get_checkdata_problems(self, obj, fix=False):
+        assert obj is None  # this is an unbound checker
+        Upload = rt.models.uploads.Upload
+        pth = dd.plugins.uploads.get_uploads_root()
+        start = len(settings.MEDIA_ROOT) + 1
+        # for filename in glob.iglob(join(pth,"**/*")):
+        for filename in Path(pth).rglob("*"):
+            # print(filename)
+            if filename.is_dir():
+                continue
+            rel_filename = str(filename)[start:]
+            qs = Upload.objects.filter(file=rel_filename)
+            n = qs.count()
+            if n == 0:
+                msg = format_lazy(_("File {} has no upload entry."), rel_filename)
+                # print(msg)
+                yield (dd.plugins.uploads.remove_orphaned_files, msg)
+                if fix and dd.plugins.uploads.remove_orphaned_files:
+                    filename.unlink()
+                    # obj = Upload(file=FieldFile(rel_filename))
+                    # # obj = Upload(file=filename)
+                    # obj.full_clean()
+                    # obj.save()
+            # else:
+            #     print("{} has {} entries.".format(filename, n))
+            # elif n > 1:
+            #     msg = _("Multiple upload entries for {} ").format(filename)
+            #     yield (False, msg)
+            #     This is no problem. A same file should be linkable to diffeerent controlers.
+
+UploadsFolderChecker.activate()
+
+
 class Volumes(dd.Table):
     model = 'uploads.Volume'
     required_roles = dd.login_required(OfficeStaff)
@@ -111,80 +237,6 @@ class UploadTypes(dd.Table):
     """
 
 
-def filename_leaf(name):
-    i = name.rfind('/')
-    if i != -1:
-        return name[i + 1:]
-    return name
-
-
-
-class Upload(mixins.Uploadable, UserAuthored, Controllable):
-    class Meta(object):
-        abstract = dd.is_abstract_model(__name__, 'Upload')
-        # verbose_name = _("Upload")
-        # verbose_name_plural = _("Uploads")
-        verbose_name = _("Upload file")
-        verbose_name_plural = _("Upload files")
-
-    upload_area = UploadAreas.field(default='general')
-    type = dd.ForeignKey("uploads.UploadType", blank=True, null=True)
-    volume = dd.ForeignKey("uploads.Volume", blank=True, null=True)
-    library_file = models.CharField(_("Library file"), max_length=255, blank=True)
-
-    description = models.CharField(
-        _("Description"), max_length=200, blank=True)
-
-    def __str__(self):
-        if self.description:
-            s = self.description
-        elif self.file:
-            s = filename_leaf(self.file.name)
-        elif self.library_file:
-            s = "{}:{}".format(self.volume.ref, self.library_file)
-        else:
-            s = str(self.id)
-        if self.type:
-            s = str(self.type) + ' ' + s
-        return s
-
-    @dd.displayfield(_("Description"))
-    def description_link(self, ar):
-        if self.description:
-            s = self.description
-        elif self.file:
-            s = filename_leaf(self.file.name)
-        elif self.type:
-            s = str(self.type)
-        else:
-            s = str(self.id)
-        if ar is None:
-            return s
-        return self.get_file_button(s)
-
-    @dd.chooser(simple_values=True)
-    def library_file_choices(self, volume):
-        if volume is None:
-            return []
-        return list(volume.get_filenames())
-
-    @dd.chooser()
-    def type_choices(self, upload_area):
-        M = dd.resolve_model('uploads.UploadType')
-        # logger.info("20140430 type_choices %s", upload_area)
-        if upload_area is None:
-            return M.objects.all()
-        return M.objects.filter(upload_area=upload_area)
-
-    def save(self, *args, **kw):
-        if self.type is not None:
-            self.upload_area = self.type.upload_area
-        super(Upload, self).save(*args, **kw)
-
-
-dd.update_field(Upload, 'user', verbose_name=_("Uploaded by"))
-
-
 class Uploads(dd.Table):
     model = 'uploads.Upload'
     required_roles = dd.login_required((OfficeUser, OfficeOperator))
@@ -207,26 +259,18 @@ class Uploads(dd.Table):
     """
 
     parameters = mixins.ObservedDateRange(
-        # user=dd.ForeignKey(
-        #     'users.User', blank=True, null=True,
-        #     verbose_name=_("Uploaded by")),
         upload_type=dd.ForeignKey(
             'uploads.UploadType', blank=True, null=True))
     params_layout = "start_date end_date user upload_type"
 
-    # simple_parameters = ['user']
-
     @classmethod
     def get_request_queryset(cls, ar, **filter):
         qs = super(Uploads, cls).get_request_queryset(ar, **filter)
         pv = ar.param_values
-
         if pv.user:
             qs = qs.filter(user=pv.user)
-
         if pv.upload_type:
             qs = qs.filter(type=pv.upload_type)
-
         return qs
 
 
@@ -381,6 +425,7 @@ class UploadsByController(AreaUploads):
     def format_upload(self, obj):
         return str(obj.type)
 
+
 @dd.receiver(dd.pre_analyze)
 def before_analyze(sender, **kwargs):
     # This is the successor for `quick_upload_buttons`.
