@@ -34,9 +34,9 @@ def mywrap(t, ls=80):
 class UserDetail(dd.DetailLayout):
 
     box1 = """
-    username user_type:20 person company
+    username user_type:20 person company partner
     first_name last_name initials
-    email language time_zone
+    email language time_zone dashboard_layout
     id created modified
     """
 
@@ -123,19 +123,38 @@ class UsersOverview(Users):
     # else:
     #     sign_in = SignInWithSocialAuth()
 
-class MySettings(Users):
+class Me(Users):
+    label = _("My settings")
     # use_as_default_table = False
     # hide_top_toolbar = True
     hide_navigator = True
     required_roles = dd.login_required()
     allow_create = False
     allow_delete = False
-    default_list_action_name = 'detail'
+    # default_list_action_name = 'detail'
+    #
+    # @classmethod
+    # def get_default_action(cls):
+    #     # if cls.detail_action is None:
+    #     #     raise Exception("20210531 {}".format(cls))
+    #     return cls.detail_action
 
     @classmethod
-    def get_default_action(cls):
-        return cls.detail_action
+    def get_row_by_pk(cls, ar, pk):
+        return ar.get_user()
 
+# class MySettings(Users):
+#     # use_as_default_table = False
+#     # hide_top_toolbar = True
+#     hide_navigator = True
+#     required_roles = dd.login_required()
+#     allow_create = False
+#     allow_delete = False
+#     default_list_action_name = 'detail'
+#
+#     @classmethod
+#     def get_default_action(cls):
+#         return cls.detail_action
 
 class Authorities(dd.Table):
     required_roles = dd.login_required(SiteAdmin)
