@@ -829,6 +829,12 @@ def get_client_ip_address(request):
     return ip or "(unknown)"  # see ticket #2605
 
 
+class AsynchronousValue:
+    def __init__(self, field, obj):
+        self.field = field
+        self.obj = obj
+
+
 def _test():
     import doctest
     doctest.testmod()
