@@ -1,13 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2019 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2012-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""Defines the model mixin :class:`BabelNamed`.
+"""Defines the model mixins :class:`BabelNamed` and :class:`BabelDesignation`.
 
 """
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from lino.core import model
 
